@@ -7,6 +7,6 @@ def safe_import(module: str, silence: bool = True, reraise: bool = False):
         return import_module(module)
     except ImportError as e:
         if not silence:
-            sys.stdout.write(f'Module {module} importing error: {e}')
+            sys.stdout.write(f'Module {module} importing error: {e}\n')
         if reraise:
             raise e
