@@ -37,24 +37,13 @@ class JSONEncoder(json.JSONEncoder):
         super().__init__(**kwargs)
 
     def default(self, o):
-        if isinstance(o, datetime.datetime):
-            r = o.isoformat()
-            if o.microsecond:
-                r = r[:23] + r[26:]
-            if r.endswith('+00:00'):
-                r = r[:-6] + 'Z'
-            return r
-
-        if isinstance(o, datetime.date):
+        if isinstance(o, (datetime.datetime, datetime.date)):
             return o.isoformat()
 
         if isinstance(o, datetime.time):
             if timezone.is_aware(o):
                 raise ValueError('JSON can\'t represent timezone-aware times.')
-            r = o.isoformat()
-            if o.microsecond:
-                r = r[:12]
-            return r
+            return o.isoformat()
 
         if isinstance(o, datetime.timedelta):
             return duration.duration_iso_string(o)
